<!-- toc -->
* [Configuration](#configuration)
* [System requirements](#system-requirements)
* [Usage](#usage)
* [Commands](#commands)
<!-- tocstop -->
# Configuration

`facetsctl` requires a connection to docker for all actions involving docker. Ensure that you have docker running on the system where `facetsctl` is running.

# System requirements

Supported node versions: >= 12.0.0

# Usage
<!-- usage -->
```sh-session
$ npm install -g @facets-cloud/facetsctl
$ facetsctl COMMAND
running command...
$ facetsctl (--version)
@facets-cloud/facetsctl/1.0.5-5058184204 linux-x64 node-v16.20.0
$ facetsctl --help [COMMAND]
USAGE
  $ facetsctl COMMAND
...
```
<!-- usagestop -->
# Commands
<!-- commands -->
* [`facetsctl generate-config CONFIG-FILE`](#facetsctl-generate-config-config-file)
* [`facetsctl help [COMMAND]`](#facetsctl-help-command)
* [`facetsctl login`](#facetsctl-login)
* [`facetsctl push`](#facetsctl-push)
* [`facetsctl refresh`](#facetsctl-refresh)

## `facetsctl generate-config CONFIG-FILE`

Convert a JSON, YAML, or properties file of a springboot application to a Facets Application JSON env section

```
USAGE
  $ facetsctl generate-config CONFIG-FILE

ARGUMENTS
  CONFIG-FILE  The JSON, YAML, or properties file to convert

DESCRIPTION
  Convert a JSON, YAML, or properties file of a springboot application to a Facets Application JSON env section
```

_See code: [dist/commands/generate-config.ts](https://github.com/facets-cloud/facetsctl/blob/v1.0.5-5058184204/dist/commands/generate-config.ts)_

## `facetsctl help [COMMAND]`

Display help for facetsctl.

```
USAGE
  $ facetsctl help [COMMAND] [-n]

ARGUMENTS
  COMMAND  Command to show help for.

FLAGS
  -n, --nested-commands  Include all nested commands in the output.

DESCRIPTION
  Display help for facetsctl.
```

_See code: [@oclif/plugin-help](https://github.com/oclif/plugin-help/blob/v5.1.12/src/commands/help.ts)_

## `facetsctl login`

Login to Facets control plane

```
USAGE
  $ facetsctl login -u <value> -t <value> -c <value> [-o <value>]

FLAGS
  -c, --cp-url=<value>          (required) URL of the Control plane
  -o, --original-error=<value>  [default: false] See original error message thrown
  -t, --access-token=<value>    (required) Personal token generated for the user
  -u, --username=<value>        (required) username of the user

DESCRIPTION
  Login to Facets control plane

EXAMPLES
  $ facetsctl login
```

_See code: [dist/commands/login.ts](https://github.com/facets-cloud/facetsctl/blob/v1.0.5-5058184204/dist/commands/login.ts)_

## `facetsctl push`

Post new docker artifacts to the facets control plane

```
USAGE
  $ facetsctl push -i <value> -a <value> -e <value> [--registration-type CLUSTER|RELEASE_STREAM]
    [--registration-value <value>] [-d <value>] [--artifactory <value>] [--debug <value>] [-r <value>]

FLAGS
  -a, --artifact-name=<value>   (required) name of the artifact as mentioned in blueprint
  -d, --description=<value>     description of the build if any
  -e, --external-id=<value>     (required) external identifier for artifact
  -i, --docker-image=<value>    (required) image location <IMAGE:TAG>
  -r, --git-ref=<value>         Git ref provided in CI Rule
  --artifactory=<value>         artifactory where image will be pushed
  --debug=<value>               [default: false] See original error message thrown
  --registration-type=<option>  mode of registration
                                <options: CLUSTER|RELEASE_STREAM>
  --registration-value=<value>  value for release stream or cluster id, based on mode of registration

DESCRIPTION
  Post new docker artifacts to the facets control plane

EXAMPLES
  $ facetsctl push
```

_See code: [dist/commands/push.ts](https://github.com/facets-cloud/facetsctl/blob/v1.0.5-5058184204/dist/commands/push.ts)_

## `facetsctl refresh`

Refresh your k8s credentials for an environment. Credentials can be refreshed using either an environment id or a combination of blueprint name and environment name.

```
USAGE
  $ facetsctl refresh [-e <value> | --environment-name <value> | --blueprint-name <value>]

FLAGS
  -e, --environment-id=<value>  Environment id for credentials needs to be refreshed
  --blueprint-name=<value>      Blueprint name using which environment was launched
  --environment-name=<value>    Environment Name for credentials needs to be refreshed

DESCRIPTION
  Refresh your k8s credentials for an environment. Credentials can be refreshed using either an environment id or a
  combination of blueprint name and environment name.

EXAMPLES
  $ facetsctl refresh
```

_See code: [dist/commands/refresh.ts](https://github.com/facets-cloud/facetsctl/blob/v1.0.5-5058184204/dist/commands/refresh.ts)_
<!-- commandsstop -->
